package com.ruoyi.web.work.controller;

import java.util.Arrays;
import java.util.List;

import com.ruoyi.common.annotation.Anonymous;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.web.work.domain.User;
import com.ruoyi.web.work.service.IUserService;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 小程序用户
 * @author lsw
 * @date 2024-07-19
 */
@Api(tags = "小程序用户管理")
@Anonymous
@RestController
@RequestMapping("/work/user")
public class UserController extends BaseController {
    @Autowired
    private IUserService userService;

    @ApiOperation(value = "获取小程序用户")
    @Anonymous
    //@PreAuthorize("@ss.hasPermi('work:user:list')")
    @GetMapping("/list")
    public TableDataInfo list(User user){
        startPage();
        List<User> list = userService.selectList(user);
        return getDataTable(list);
    }

    @ApiOperation(value = "根据id查询小程序用户")
    @Anonymous
    //@PreAuthorize("@ss.hasPermi('work:user:query')")
    @GetMapping(value = "/detail/{id}")
    public AjaxResult detail(@PathVariable("id") Long id){
        return AjaxResult.success(userService.getById(id));
    }

    @ApiOperation(value = "添加小程序用户")
    @Anonymous
    //@PreAuthorize("@ss.hasPermi('work:user:add')")
    @Log(title = "小程序用户", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    public AjaxResult add(@RequestBody User user){
        return toAjax(userService.save(user));
    }

    @ApiOperation(value = "修改小程序用户")
    @Anonymous
    //@PreAuthorize("@ss.hasPermi('work:user:edit')")
    @Log(title = "小程序用户", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody User user){
        return toAjax(userService.updateById(user));
    }

    @ApiOperation(value = "删除小程序用户")
    @Anonymous
    //@PreAuthorize("@ss.hasPermi('work:user:remove')")
    @Log(title = "小程序用户", businessType = BusinessType.DELETE)
    @GetMapping("/remove/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids){
        return toAjax(userService.removeByIds(Arrays.asList(ids)));
    }
}
